/**
 * This class contains information about a product that can be purchased, or
 * obtained for free from reward points.
 * 
 * @author Alan Williams
 */
public class Product
{
	/**
	 * A description of the product.
	 */
	private String name;

	/**
	 * Regular price of the product.
	 */
	private double cost;

	/**
	 * Number of points to obtain this product for free.
	 */
	private int pointsRequired;

	/**
	 * Constructor for a new Product.
	 * 
	 * @param theName
	 *            Description of the product.
	 * @param theCost
	 *            Cost to purchase the product.
	 * @param thePointsRequired
	 *            Number of points required to get the product for free.
	 */
	public Product( String theName, double theCost, int thePointsRequired )
	{
		this.name = theName;
		this.cost = theCost;
		this.pointsRequired = thePointsRequired;
	}

	/**
	 * Returns the product description.
	 * 
	 * @return A String that describes the product.
	 */
	public String getName( )
	{
		return this.name;
	}

	/**
	 * Returns the cost of the Product.
	 * 
	 * @return A double containing the product cost.
	 */
	public double getCost( )
	{
		return this.cost;
	}

	/**
	 * Returns the number of points required to obtain this product for free.
	 * 
	 * @return An int containing the number of points.
	 */
	public int getPointsRequired( )
	{
		return this.pointsRequired;
	}
}
