import junit.framework.Assert;
import junit.framework.TestCase;
/**
 * 
 */

/**
 * @author Alan Williams
 *
 */
public class CardHolderTest extends TestCase
{

	/**
	 * Test method for 'CardHolder.CardHolder(String, int)'.
	 */
	public void testCardHolder( )
	{
		String nameTestData = "Alan";
		int cardNumberTestData = 123456;
		
		CardHolder ch = new CardHolder( nameTestData, cardNumberTestData );

		boolean expected = false;
		boolean actual = CardHolder.enoughPoints(ch, 1);
		Assert.assertEquals(expected, actual);
	}

	/**
	 * Test method for 'CardHolder.getName()'.
	 */
	public void testGetName( )
	{
		String nameTestData = "Daniel";
		int cardNumberTestData = 654321;
		
		CardHolder ch = new CardHolder( nameTestData, cardNumberTestData );
		
		String expectedName = new String( nameTestData );
		String actualName = ch.getName();
		Assert.assertEquals( expectedName, actualName );
	}

	/**
	 * Test method for 'CardHolder.getCardNumber()'.
	 */
	public void testGetCardNumber( )
	{
		String nameTestData = "Grace";
		int cardNumberTestData = 165243;
		
		CardHolder ch = new CardHolder( nameTestData, cardNumberTestData );
		
		int expectedNumber = cardNumberTestData;
		int actualNumber = ch.getCardNumber();
		Assert.assertEquals( expectedNumber, actualNumber );
	}

	/**
	 * Test method for 'CardHolder.setNumberOfPoints(int)'.
	 */
	public void testSetNumberOfPoints( )
	{
		String nameTestData = "Fred";
		int cardNumberTestData = 426531;
		int pointsTestData = 4000;
		
		CardHolder ch = new CardHolder( nameTestData, cardNumberTestData );
		
		ch.setNumberOfPoints(pointsTestData);
		
		boolean expected = true;
		boolean actual = CardHolder.enoughPoints(ch, pointsTestData);
		Assert.assertEquals(expected, actual);

		expected = false;
		actual = CardHolder.enoughPoints(ch, pointsTestData + 1);
		Assert.assertEquals(expected, actual);
}

	/**
	 * Test method for 'CardHolder.adjustPoints(int)' with positive adjustment.
	 */
	public void testAdjustPointsUp( )
	{
		String nameTestData = "Bob";
		int cardNumberTestData = 561234;
		int pointsTestData = 4000;
		int adjustTestData = 147;
		
		CardHolder ch = new CardHolder( nameTestData, cardNumberTestData );
		
		ch.setNumberOfPoints(pointsTestData);
		ch.adjustPoints(adjustTestData);
		
		boolean expected = true;
		boolean actual = CardHolder.enoughPoints(ch, pointsTestData + adjustTestData );
		Assert.assertEquals(expected, actual);

		expected = false;
		actual = CardHolder.enoughPoints(ch, pointsTestData + adjustTestData + 1);
		Assert.assertEquals(expected, actual);

	}

	/**
	 * Test method for 'CardHolder.adjustPoints(int)' with negative adjustment.
	 */
	public void testAdjustPointsDown( )
	{
		String nameTestData = "Bob";
		int cardNumberTestData = 561234;
		int pointsTestData = 6000;
		int adjustTestData = -500;
		
		CardHolder ch = new CardHolder( nameTestData, cardNumberTestData );
		
		ch.setNumberOfPoints(pointsTestData);
		ch.adjustPoints(adjustTestData);
		
		boolean expected = true;
		boolean actual = CardHolder.enoughPoints(ch, pointsTestData + adjustTestData );
		Assert.assertEquals(expected, actual);

		expected = false;
		actual = CardHolder.enoughPoints(ch, pointsTestData + adjustTestData + 1);
		Assert.assertEquals(expected, actual);

	}

	/**
	 * Test method for 'CardHolder.enoughPoints(CardHolder, int)'.
	 */
	public void testEnoughPoints( )
	{
		CardHolder ch1;
		CardHolder ch2;

		String nameTestData = "Bob";
		int cardNumberTestData = 561234;
		int pointsTestData1 = 6000;
		int pointsTestData2 = 6001;

		ch1 = new CardHolder( nameTestData, cardNumberTestData );
		ch2 = new CardHolder( nameTestData, cardNumberTestData );
		
		ch1.setNumberOfPoints(pointsTestData1);
		ch2.setNumberOfPoints(pointsTestData2);
		
		boolean expected = true;
		boolean actual = CardHolder.enoughPoints(ch2, pointsTestData2);
		Assert.assertEquals(expected, actual); 
		
		expected = false;
		actual = CardHolder.enoughPoints(ch1, pointsTestData2);
		Assert.assertEquals(expected, actual);
	}

}
